@@ -1,6 +1,6 @@
 from .version import __version__
 from .flops_counter import *
 from .meanstd import *
-from .trainer import train_cifar, train_imagenet
-from .inference import infer_cifar, infer_imagenet
-from .utils import CrossEntropyLabelSmooth , get_learning_rate, create_exp_dir, save_checkpoint
\ No newline at end of file
+from .fit import learning
+from .utils import CrossEntropyLabelSmooth , get_learning_rate, create_exp_dir, save_checkpoint
+from .autoaugment import *
\ No newline at end of file
